Ocens2Surv: Ocens2Surv

View source: R/Ocens.r

Ocens2SurvR Documentation

Ocens2Surv

Description

Converts an Ocens object to the simplest Surv object that works for the types of censoring that are present in the data.

Usage

Ocens2Surv(Y)

Arguments

Y

an Ocens object

Value

a Surv object

Examples

Y <- Ocens(1:3, c(1, Inf, 3))
Ocens2Surv(Y)

rms documentation built on Feb. 18, 2026, 9:07 a.m.