Olinks: Likehood-Based Statistics for Other Links for orm Fits

View source: R/Olinks.r

OlinksR Documentation

Description

Likehood-Based Statistics for Other Links for orm Fits

Usage

Olinks(
  object,
  links = c("logistic", "probit", "loglog", "cloglog"),
  dec = 3,
  gradtol = 0.001
)

Arguments

object

an object created by orm with ⁠x=TRUE, y=TRUE⁠

links

a vector of links to consider other than the one used to get object

dec

number of digits to the right of the decimal place to round statistics to

gradtol

tolerance for convergence on the absolute gradient; see lrm.fit and orm.fit.

Value

data frame. The R2 column is from the last adjusted R^2 computed by orm, which adjustes for the effective sample size and the number of betas.

Author(s)

Frank Harrell

Examples

## Not run: 
f <- orm(y ~ x1 + x2, family='loglog', x=TRUE, y=TRUE)
Olinks(f)

## End(Not run)

rms documentation built on Feb. 18, 2026, 9:07 a.m.

Related to Olinks in rms...