is.na.Ocens: is.na Method for Ocens Objects

View source: R/Ocens.r

is.na.OcensR Documentation

is.na Method for Ocens Objects

Description

is.na Method for Ocens Objects

Usage

## S3 method for class 'Ocens'
is.na(x)

Arguments

x

an object created by Ocens

Value

a logical vector whose length is the number of rows in x, with TRUE designating observations having one or both columns of x equal to NA

Examples

Y <- Ocens(c(1, 2, NA, 4))
Y
is.na(Y)

rms documentation built on Feb. 18, 2026, 9:07 a.m.