Process Special Multiple Imputation Output From fit.mult.impute
# S3 method for fit.mult.impute
processMI(
object,
which = c("validate", "calibrate"),
plotall = TRUE,
nind = 0,
...
)an object like a validate or calibrate result obtained when no multiple imputation was done. This object is suitable for print and plot methods for these kinds of resampling validation objects.
a fit object created by fit.mult.impute
specifies which component of the extra output should be processed
set to FALSE when which='calibrate' to suppress having ggplot render a graph showing calibration curves produced separately for all the imputations
set to a positive integer to use base graphics to plot a matrix of graphs, one each for the first nind imputations, and the overall average calibration curve at the end
ignored
Frank Harrell
Processes a funresults object stored in a fit object created by fit.mult.impute when its fun argument was used. These objects are typically named validate or calibrate and represent bootstrap or cross-validations run separately for each imputation. See this for a case study.